function Experiment2(P, plot_title)
% EXPERIMENT2    Run Experiment2 and plot the results
%
% Experiment2(P, plot_title) perform the tests on the conditioning of the
% matrix polynomial described by the cell array P and use plot_title as the
% title for the plot that will be generated. 
%
% Differently from polyeig, this function take the coefficients of P in
% degree descending order (this is done in order to share some code between 
% scalar and matrix polynomials). 
%
% This funtion tests a matrix polynomial created with a call to
% Example2() or obtained from the NLEVP archive. In the latter case, be
% sure to reverse the order of the coefficients to get the expected result.
% 

% First build a standard Frobenius linearization that we will use
% as a reference.
% F = balance(bcomp(P{:}));
F = bcomp(P{:});

% We want to show that choices of the nodes b_i near to the eigenvalues
% of P lead to well-conditioned lineraziations. So we may choose as b_i
% the mean of a block of eigenvalue modules. 

l = sort(abs(eig(F)));
m = size(P{1}, 1);
n = length(P);

b = [];
for i = 1:n-1
    b = [ b , exp(2*pi*1i*i / (2)) * mean(l((i-1)*m+1:i*m)) ];
end

A = seccomp(b, P{:});

% As a third experiment, we try to use the estimates on the moduli given by
% Pellet instead on pre-computing the eigenvalues. 

% Invert the coefficient with the minimum conditioning. 
% [v,ind] = min(arrayfun(@(i) norm(P{i}), 1 : length(P)))
S = {}; for i = 1 : length(P); S{i} = P{1} \ P{i}; end;
[v,l] = mnewtpol(P{:});

b = [];
for i = 1 : length(l)
    b = [ b , (-1)^(sum(l(1:i-1))) * exp(2*pi*1i*((1:l(i)) - 1) ./ l(i)) .* v(i) ];
end

% Here would be a good place to experiment with other choices of b(i) and
% see how the conditioning changes. For example, for the orr_sommerfeld
% problem, try adding b(1) = 5 in here. 
% b(1) = 5;

AA = seccomp(b, P{:});

% Plot the conditioning of the eigenvalues
t = 1 : (n-1)*m;

semilogy (t, condeig(F), 'o-', t, condeig(A), '*-', t, condeig(AA), 'x-');
legend('Frobenius linearization', 'Secular linearization - eivals', 'Secular linearization - Pellet');
xlabel('eigenvalues');
ylabel('Conditioning');

title(plot_title);
