function Experiment3()
%EXPERIMENT3    Test polyeig and the secular linearization on the problem
% described in the last numerical example on the paper "On a class of
% matrix pencils equivalent to a given matrix polynomial". 
%
% Please note that the file 'example_zeros.mat' must be in the same folder
% of this script in order to be able to load the data. 

load example_zeros

% Use polyeig to solve the PEP
pei = polyeig(a0,z,a1,z,z,z,z,z,z,a2,z,a3);

% Now use the secular linearization coupled with the tropical roots
[v,l] = mnewtpol(a0,z,a1,z,z,z,z,z,z,a2,z,a3);
b = [];
for i = 1 : length(l)
    b = [ b , (-1)^(sum(l(1:i-1))) * exp(2*pi*1i*((1:l(i)) - 1) ./ l(i)) .* v(i) ];
end

A = seccomp(b,a3,z,a2,z,z,z,z,z,z,a1,z,a0);
sei = eig(A);

% We need to compare the eigenvalues. Since sort may not work consintently
% on complex conjugate pairs, we compare the moduli. 

acei = sort(abs(cei));
asei = sort(abs(sei));
apei = sort(abs(pei));

t = 1 : length(sei);
semilogy (t, abs(acei - apei) ./ acei, t, abs(acei - asei) ./ acei);

legend('polyeig', 'secular');
xlabel('eivals');
ylabel('Relative error');

end