function [a,b]=bcomp(varargin)
%BCOMP	Create a Frobenius linearization for the given matrix polynomial
%
% F = bcomp(Pn, ..., P0) creates a Frobenius linearization for the matrix
% polynomial Pn*x^n + ... + P1*x + P0. 
%
% [A,B] = bcomp(Pn, ..., P0) creates the Frobenius pencil associated to
% the same matrix polynomial. 

n=nargin-1;
m=size(varargin{1},1);
a=diag(ones(m*n-m,1),-m);

b = eye(n*m);

for k=1:n
  if nargout == 1
    a((k-1)*m+1:k*m,n*m-m+1:n*m)=-varargin{1}\varargin{n-k+2};
  else
    a((k-1)*m+1:k*m,n*m-m+1:n*m)=-varargin{n-k+2};
  end
end;

if nargout == 2
    b((n-1)*m+1:n*m,(n-1)*m+1:n*m) = varargin{1};
end
